require 'bundler'
Bundler.setup

require "nfse_carioca"
require "pry"
require "vcr"

def file_path(filename)
  File.join(File.dirname(__FILE__), "fixtures", filename)
end

VCR.configure do |config|
  config.cassette_library_dir = "spec/fixtures/vcr_cassettes"
  config.hook_into :webmock
  config.configure_rspec_metadata!
end

Dir[File.join(File.dirname(__FILE__), '/support/**/*.rb')].each { |f| require f }

RSpec.configure do |config|
  config.expect_with :rspec do |expectations|
    expectations.include_chain_clauses_in_custom_matcher_descriptions = true
  end

  config.mock_with :rspec do |mocks|
    mocks.verify_partial_doubles = true
  end

  config.before do
    NfseCarioca.configure do |nfse|
      nfse.cnpj = "12390095000186"
      nfse.inscricao_municipal = "04807995"
      nfse.test_mode = true
    end
  end

  config.filter_run :focus
  config.run_all_when_everything_filtered = true

  config.disable_monkey_patching!

  config.warnings = true

  if config.files_to_run.one?
    config.default_formatter = 'doc'
  end

  config.profile_examples = 5

  config.order = :random

  Kernel.srand config.seed
end
